# gisboys-library
Python library used and complemented by GisSense  
Maintained by GisSense  
https://www.gissense.com  


# LogHelper
Logging class for easy logging

### ILogHelper
Interface for LogHelper (Pythonic way as an abstract class)
